@@ -503,7 +503,7 @@ const labels <- '';
 
 def test_struct_attr_access():
     text = """
-const labels <- struct(a=1, b=2, c=3);
+const labels <- struct(a->1, b->2, c->3);
 
 
 select
