@@ -23,6 +23,7 @@ from trilogy.core.constants import CONSTANT_DATASET
 from trilogy.core.enums import (
     ComparisonOperator,
     Derivation,
+    FunctionClass,
     FunctionType,
     JoinType,
     Modifier,
@@ -375,6 +376,12 @@ class CTE(BaseModel):
                 return check_is_not_in_group(c.lineage.content)
             if c.derivation == Derivation.CONSTANT:
                 return True
+            if (
+                c.purpose == Purpose.CONSTANT
+                and isinstance(c.lineage, BuildFunction)
+                and c.lineage.operator in FunctionClass.AGGREGATE_FUNCTIONS.value
+            ):
+                return True
             if c.purpose == Purpose.METRIC:
                 return True
 
